/*
%-----------------------------------------------------------------------------
% PROJET  : STS INTERFACE
%
% MODULE  : HEADER STS INTERFACE
%
% VERSION : cf #define ci-aprs
%
% FICHIER : sts.h
%
% Dclaration des prototypes des fonctions STS - INTERFACE
%-----------------------------------------------------------------------------
%
% EDS DHU - 09/04/03 - Cration du .h
%
% EDS OCL - 06/06/03 - Defect 91 : Rectification du prototype de InitTrace()
%
% EDS OCL - 04/07/03 - Defect 115 : Nettoyage de stsitf.h (devenu sts.h)
%
%-----------------------------------------------------------------------------
*/

#ifndef __STSITF_H
#define __STSITF_H
#define __STSITF_VERSION "0103"
/* Ne pas oublier d'impacter idef.h aussi */

#ifdef __cplusplus
extern "C" {
#endif

/*
% Bibliothques ANSI ou systme
%------------------------------
*/


/*
% Fichiers h inclus
%------------------
*/

#include "sys_dep.h"
/*
% Macros et Constantes
%---------------------
*/

/* OCL - Defect 115 : Suppression du #define G_xxx ici mme */

/* OCL - Defect 115 : Suppression du second #ifdef _cplusplus ici mme */


/*********************************************************************************
 ************************* Fonctions rentrantes *********************************
 *********************************************************************************/

/*
%-----------------------------------------------------------------------------
% STS_Tarification
%
% Rle : Tarification de la part complmentaire des actes de la facture
%
% Paramtres d'entre :
%			MotifAppel (char) : 1er appel ('P') ou Appel sur echec de
%				tarification ('E').
%			ZDonneesEntree (void*) : Zone d'change fournie par le Progiciel
%				contenant toutes les informations sur la facture
%			TailleDonneesEntree (size_t) : Taille de la zone d'change Zin
%
% Paramtres de sortie :
%			ZDonneesSortie (void**) : Zone d'change fournie par le module STS appel
%				contenant toutes les informations modifies de la facture
%				en entre et de nouvelles informations.
%			TailleDonneesSortie (size_t*) : Taille de la zone d'change Zout
%
% Valeur retourne :
%			OK si pas d'erreur
%			ERR_STS_NON_INITIALISE si module STS non initialis
%        et les codes d'erreurs de la tarification du module STS appel
% 
%-----------------------------------------------------------------------------
*/
/* OCL - Defect 115 : Remplacement PTR par FARPTR */
typedef unsigned short (API_ENTRY FARPTR STS_Tarification)(char	MotifAppel, void FARPTR	ZDonneesEntree,
														   size_t TailleDonneesEntree, void FARPTR FARPTR ZDonneesSortie,
														   size_t FARPTR TailleDonneesSortie);

/* Fonction simplifie */
/* OCL - Defect 115 : Remplacement STS_SIM par SGD */
#ifdef SGD
typedef unsigned short (API_ENTRY FARPTR STS_Tarification_S)(char MotifAppel, unsigned short NumeroSession);
#endif

/*
%-----------------------------------------------------------------------------
% STS_Assistance
%
% Rle : Assistance  la facturation.
%
% Paramtres d'entre :
%			MotifAppel (char) : 1er appel ('P') ou Appel sur echec de
%				tarification ('E').
%			PorteeAppel (ushort) : 0 pour une assistance sur toute la facture.
%				1..n pour une assistance sur un acte de rang donn /zone
%			ZDonneesEntree (void*) : Zone d'change fournie par le Progiciel
%				contenant toutes les informations sur la facture
%			TailleDonneesEntree (size_t) : Taille de la zone d'change Zin
%
% Paramtres de sortie :
%			ZDonneesSortie (void**) : Zone d'change fournie par le module STS appel
%			TailleDonneesSortie (size_t*) : Taille de la zone d'change Zout
%
% Valeur retourne : (idem Tarification)
%			OK si pas d'erreur
%			ERR_STS_NON_INITIALISE si module STS non initialis
%        et les codes d'erreurs de la tarification du module STS appel
%
%-----------------------------------------------------------------------------
*/
/* OCL - Defect 115 : Remplacement PTR par FARPTR */
typedef unsigned short (API_ENTRY FARPTR STS_Assistance)(char MotifAppel, unsigned short PorteeAppel,
														 void FARPTR ZDonneesEntree, size_t	TailleDonneesEntree,
														 void FARPTR FARPTR	ZDonneesSortie, size_t FARPTR TailleDonneesSortie);

/* Fonction simplifie */
#ifdef SGD
typedef unsigned short (API_ENTRY FARPTR STS_Assistance_S)(char MotifAppel, unsigned short PorteeAppel,
														   unsigned short NumeroSession);
#endif

/*
%-----------------------------------------------------------------------------
% STS_LireVersion
%
% Rle : Lecture de la version de ce module et du fichier de ces tables externes
%			dans le groupe 3780. Appeller la lecture de version de chaque module STS 
%        puis recopier la rponse 3780 de chacun dans la zone de sortie.
%
% Paramtres d'entre : aucun
%
% Paramtres de sortie :
%			ZDonneesSortie (void**) : Zone d'change fournie par ce module
%				contenant les versions (grp 3780) demandes.
%			TailleDonneesSortie (size_t*) : Taille de la zone d'change Zout
%
% Valeur retourne :
%			OK si pas d'erreur
%			ERR_STS_NON_INITIALISE si module STS non initialis
%			ERR_ZOUT si ZDonneesSortie==NULL ou TailleDonneesSortie==NULL
%			ERR_ZONE_ALLOC si mmoire insuffisante pour allouer la Zout
%
%-----------------------------------------------------------------------------
*/
/* OCL - Defect 115 : Remplacement PTR par FARPTR */
typedef unsigned short (API_ENTRY FARPTR STS_LireVersion)(void FARPTR FARPTR ZDonneesSortie, size_t FARPTR TailleDonneesSortie);

/* Fonction simplifie */
#ifdef SGD
typedef unsigned short (API_ENTRY FARPTR STS_LireVersion_S)(unsigned short NumeroSession);
#endif

/*
%-----------------------------------------------------------------------------
% STS_InitTrace
%
% Rle : Initialisation des traces du module STS-Interface dans un fichier log.
%			Cette fonction permet d'activer ou dsactiver (niveau 0) les
%			traces. Une activation requiert un nom de fichier et un mode
%			d'ouverture. Un changement de niveau peut se faire sur le mme
%			fichier ou sur un diffrent s'il est prcis en entre
%
% Paramtres d'entre :
%			NomFichier (char*) : Chemin et nom de fichier de trace
%			ModeOuverture (char*) : Mode d'ouverture du fichier de trace
%				"a", "w" (,"ab", "wb").
%			Module (ushort) : n de module 0  5 (6=TOUS)
%			Niveau (uchar) : Niveau de trace : 0 signifie pas de trace, 1
%				signifie traces de profondeur 8 et >=2 signifie traces sans limite
%				de profondeur et activation traces module STS_SI
%
% Paramtres de sortie : aucun
%
% Valeur retourne :
%			OK si pas d'erreur
%			ERR_PARAM si NomFichier/ModeOuverture incorrect quand Niveau > 0
%			ERR_TRACE_FILE si erreur d'ouverture du fichier de trace
%
%-----------------------------------------------------------------------------
*/
/* OCL - Defect 91 : Rectification du prototype de InitTrace() */
/* OCL - Defect 115 : Remplacement PTR par FARPTR */
typedef unsigned short (API_ENTRY FARPTR STS_InitTrace)(const char FARPTR pathConf, const char FARPTR	ModeOuverture,
														unsigned short Module, unsigned char Niveau);

/*********************************************************************************
 ************************* Fonctions d'initialisation et de terminaison  *********
 *********************************************************************************/

/*
%-----------------------------------------------------------------------------
% STS_InitLIB
%
% Rle : Initialisation du module STS-Interface : Chargement des tables externes
%			et suivi de parc. Appel de l'nitialisation de chaque module STS 
%
% Paramtres d'entre : aucun
%			
% Paramtres de sortie : aucun
%
% Valeur retourne :
%			OK si pas d'erreur
%			ERR_INTERNE_ITF si erreur interne du module STS-Interface (ou STS SI)
%			ERR_MEM_DISPO si plus de mmoire disponible
%			ERR_PKG_PATH_INI si le chemin d'accs au fichier binaire est
%				inconnu (fichier de configuration inaccessible ou information
%				manquante)
%			ERR_ITF_PKG_ACCES si fichier binaire de table inaccessible
%			ERR_ITF_PKG_VER si version du fichier incohrent avec version du
%				module STS-Interface (dans les deux sens)
%			ERR_ITF_PKG_CRC si CRC du fichier binaire est incorrect
%			ERR_ITF_PKG_FORME si format du fichier incorrect
%			ERR_ITF_PKG_INCPT s'il manque une table dans le fichier binaire
%			ERR_ITF_PKG_NOM si le nom du fichier est diffrent du nom dans
%				l'en-tte du fichier.
%			les codes suivants ne sont pas des erreurs fatales (non bloquant)
%				mais juste des avertissements
%				WAR_STS_DEJA_INITIALISE si module dj initialis
%				WAR_ADM_PATH si chemin au suivi de parc non trouv dans fichier
%					de configuration des produits SV
%				WAR_ADM_FILE si impossible de crer les fichiers de suivi de
%					parc
%        ET les codes de retour de chaque module STS appel
%
%-----------------------------------------------------------------------------
*/
/* extern unsigned short API_ENTRY STS_InitLIB(); */
/*
%-----------------------------------------------------------------------------
% STS_InitLIB2
%
% Rle : Initialisation du module STS-Interface : Chargement des tables externes
%			et suivi de parc. Appel de l'nitialisation de chaque module STS 
%
% Paramtres d'entre :
%			NomFichierIni (char*) : Chemin et nom du fichier de configuration des
%				produits SESAM Vitale du poste de travail (sesam.ini)
%
% Paramtres de sortie : aucun
%
% Valeur retourne :
%			OK si pas d'erreur
%			ERR_INTERNE_ITF si erreur interne du module STS-Interface (ou STS SI)
%			ERR_MEM_DISPO si plus de mmoire disponible
%			ERR_PKG_PATH_INI si le chemin d'accs au fichier binaire est
%				inconnu (fichier de configuration inaccessible ou information
%				manquante)
%			ERR_ITF_PKG_ACCES si fichier binaire de table inaccessible
%			ERR_ITF_PKG_VER si version du fichier incohrent avec version du
%				module STS-Interface (dans les deux sens)
%			ERR_ITF_PKG_CRC si CRC du fichier binaire est incorrect
%			ERR_ITF_PKG_FORME si format du fichier incorrect
%			ERR_ITF_PKG_INCPT s'il manque une table dans le fichier binaire
%			ERR_ITF_PKG_NOM si le nom du fichier est diffrent du nom dans
%				l'en-tte du fichier.
%			les codes suivants ne sont pas des erreurs fatales (non bloquant)
%				mais juste des avertissements
%				WAR_STS_DEJA_INITIALISE si module dj initialis
%				WAR_ADM_PATH si chemin au suivi de parc non trouv dans fichier
%					de configuration des produits SV
%				WAR_ADM_FILE si impossible de crer les fichiers de suivi de
%					parc
%        ET les codes de retour de chaque module STS appel
%
%-----------------------------------------------------------------------------
*/
typedef unsigned short (API_ENTRY FARPTR STS_InitLIB2)(const char FARPTR nomFichierIni);

/*
%-----------------------------------------------------------------------------
% STS_TermLIB
%
% Rle : Terminaison du module STS-Interface : Dchargement des tables externes.
%
% Paramtres d'entre : aucun
%
% Paramtres de sortie : aucun
%
% Valeur retourne :
%			OK si pas d'erreur
%			ERR_INTERNE_ITF si erreur interne du module STS-Interface (ou STS SI)
%
%-----------------------------------------------------------------------------
*/
typedef unsigned short (API_ENTRY FARPTR STS_TermLIB)(void);

/*********************************************************************************
 ************************* Fonctions de gestion de la mmoire  *******************
 *********************************************************************************/

/*
%-----------------------------------------------------------------------------
% STS_AllouerZoneMem
%
% Rle : Allocation d'une zone d'change de sortie par STS Interface.
%			Cette fonction permet la rallocation d'une zone d'change.
%			L'allocation d'une nouvelle zone d'change ncessite un pointeur
%			NULL en entre !
%			Cette fonctio est  utiliser conjointement avec STS_LibererZoneMem
%			pour faciliter le Debugage (zone alloue par l'crivain)
%
% Paramtres d'entre :
%			Taille (size_t) : Taille de la zone d'change  allouer.
%
% Paramtres d'entre et de sortie :
%			Zone (void**) : Zone d'change pralloue en entre (ou NULL).
%				Zone alloue (ralloue) par le module STS-Interface.
%
% Valeur retourne :
%			OK si pas d'erreur
%			ERR_ZOUT si Zone==NULL ou Taille==0
%			ERR_ZONE_ALLOC si plus de mmoire disponible
%
%-----------------------------------------------------------------------------
*/
/* OCL - Defect 115 : Remplacement PTR par FARPTR */
typedef unsigned short (API_ENTRY FARPTR STS_AllouerZoneMem)(void FARPTR FARPTR	Zone, size_t Taille);


/*
%-----------------------------------------------------------------------------
% STS_LibererZoneMem
%
% Rle : Libration de la zone d'change de sortie par STS Interface.
%
% Paramtres d'entre :
%			Zone (void*) : Zone d'change  librer (alloue prcdemment par
%				le module STS-Interce par STS_AllouerZoneMem).
%
% Paramtres de sortie : aucun
%
% Valeur retourne : aucune
%
%-----------------------------------------------------------------------------
*/
/* OCL - Defect 115 : Remplacement PTR par FARPTR */
typedef void (API_ENTRY FARPTR STS_LibererZoneMem)(void FARPTR Zone);

#ifdef __cplusplus
}
#endif

#endif /* __STSITF_H */
